@@ -1,6 +1,6 @@
 from hashlib import sha1
 
-from purehash._sha1 import SHA1
+from purehash.algorithms._sha1 import SHA1
 from purehash._util import random_tests
 
 
